@@ -2,8 +2,7 @@ from .cvae import CVAE
 from .scarches import scArches
 from .scarchesnb import scArchesNB
 from .scarcheszinb import scArchesZINB
-from .scanet import scANet
-
+from ._adaptor import Adaptor
 __all__ = (
-    'scArches', 'CVAE', 'scANet', 'scArchesNB', 'scArchesZINB'
+    'scArches', 'CVAE', 'scArchesNB', 'scArchesZINB'
 )
