@@ -12,6 +12,7 @@ from keras.utils import to_categorical
 from keras.utils.generic_utils import get_custom_objects
 from keras import backend as K
 from scipy import sparse
+from tensorflow.random import set_seed
 
 from scarches.models._activations import ACTIVATIONS
 from scarches.models._callbacks import ScoreCallback
@@ -28,8 +29,8 @@ class CVAE(object):
         ----------
         x_dimension: int
             number of gene expression space dimensions.
-        n_conditions: int
-            number of conditions used for one-hot encoding.
+        n_conditions: list
+            list of unique conditions (i.e. batch ids) in the data used for one-hot encoding.
         z_dimension: int
             number of latent space dimensions.
         task_name: str
@@ -71,7 +72,8 @@ class CVAE(object):
         self.alpha = kwargs.get("alpha", 0.0001)
         self.eta = kwargs.get("eta", 1.0)
         self.dr_rate = kwargs.get("dropout_rate", 0.1)
-        self.model_path = os.path.join(kwargs.get("model_path", "./models/CVAE/"), self.task_name)
+        self.model_base_path = kwargs.get("model_path", "./models/CVAE/")
+        self.model_path = os.path.join(self.model_base_path, self.task_name)
         self.loss_fn = kwargs.get("loss_fn", 'nb')
         self.ridge = kwargs.get('ridge', 0.1)
         self.scale_factor = kwargs.get("scale_factor", 1.0)
@@ -82,6 +84,9 @@ class CVAE(object):
         self.architecture = kwargs.get("architecture", [128, 128])
         self.size_factor_key = kwargs.get("size_factor_key", 'size_factors')
         self.device = kwargs.get("device", "gpu") if len(K.tensorflow_backend._get_available_gpus()) > 0 else 'cpu'
+        self.seed = kwargs.get('seed', 2020)
+        set_seed(self.seed)
+
 
         self.gene_names = kwargs.get("gene_names", None)
         self.model_name = kwargs.get("model_name", "cvae")
@@ -112,6 +117,7 @@ class CVAE(object):
             "gene_names": self.gene_names,
             "condition_encoder": self.condition_encoder,
             "train_device": self.device,
+            "seed": self.seed,
         }
 
         self.training_kwargs = {
@@ -121,7 +127,7 @@ class CVAE(object):
             "ridge": self.ridge,
             "scale_factor": self.scale_factor,
             "clip_value": self.clip_value,
-            "model_path": self.model_path,
+            "model_path": self.model_base_path,
         }
 
         self.init_w = keras.initializers.glorot_normal()
@@ -153,6 +159,7 @@ class CVAE(object):
             "gene_names": self.gene_names,
             "condition_encoder": self.condition_encoder,
             "train_device": self.device,
+            "seed": self.seed,
         }
 
         self.training_kwargs = {
@@ -162,7 +169,7 @@ class CVAE(object):
             "ridge": self.ridge,
             "scale_factor": self.scale_factor,
             "clip_value": self.clip_value,
-            "model_path": self.model_path,
+            "model_path": self.model_base_path,
         }
 
     @classmethod
