@@ -27,8 +27,8 @@ class scArches(CVAE):
         ----------
         x_dimension: int
             number of gene expression space dimensions.
-        conditions: int
-            number of conditions used for one-hot encoding.
+        conditions: list
+            list of unique conditions (i.e. batch ids) in the data used for one-hot encoding.
         z_dimension: int
             number of latent space dimensions.
         task_name: str
@@ -126,6 +126,8 @@ class scArches(CVAE):
         if new_params:
             class_config.update(new_params)
 
+        model_path = class_config.get("model_path", './')
+
         return cls(**class_config)
 
     def _output_decoder(self, h):
